/****************************************************************************
*  This file is part of the lpc1000 port for the TNKernel RTOS
*
*  Copyright (c) 2009 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
****************************************************************************
*  History:
*
*  26.09.2009  mifi   First Version
****************************************************************************/
#if defined(TN_ARCH_CM3) && defined(TN_PORT_STM32)

/*=========================================================================*/
/*  Includes                                                               */
/*=========================================================================*/
#include "tn.h"

/*=========================================================================*/
/*  DEFINE: All Structures and Common Constants                            */
/*=========================================================================*/
typedef void (*IRQ_FUNC)(void);

extern IRQ_FUNC IRQTable[];

/*=========================================================================*/
/*  DEFINE: Definition of all public Data                                  */
/*=========================================================================*/

/*=========================================================================*/
/*  DEFINE: Definition of all local Data                                   */
/*=========================================================================*/

/*=========================================================================*/
/*  DEFINE: Definition of all local Procedures                             */
/*=========================================================================*/

/*=========================================================================*/
/*  DEFINE: All code exported                                              */
/*=========================================================================*/

/***************************************************************************/
/*  xxx_IrqHandler                                                         */
/*                                                                         */
/*  The handler here will be used to jump to user handler                  */
/*  installed by tn_irq_install()                                          */
/*                                                                         */
/*  In    : none                                                           */
/*  Out   : none                                                           */
/*  Return: none                                                           */
/***************************************************************************/

void WWDG_IRQHandler (void)
{
   IRQTable[WWDG_IRQHandler_ID]();
   tn_int_exit();
}

void PVD_IRQHandler (void)
{
   IRQTable[PVD_IRQHandler_ID]();
   tn_int_exit();
}

void TAMPER_IRQHandler (void)
{
   IRQTable[TAMPER_IRQHandler_ID]();
   tn_int_exit();
}

void RTC_IRQHandler (void)
{
   IRQTable[RTC_IRQHandler_ID]();
   tn_int_exit();
}

void FLASH_IRQHandler (void)
{
   IRQTable[FLASH_IRQHandler_ID]();
   tn_int_exit();
}

void RCC_IRQHandler (void)
{
   IRQTable[RCC_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI0_IRQHandler (void)
{
   IRQTable[EXTI0_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI1_IRQHandler (void)
{
   IRQTable[EXTI1_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI2_IRQHandler (void)
{
   IRQTable[EXTI2_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI3_IRQHandler (void)
{
   IRQTable[EXTI3_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI4_IRQHandler (void)
{
   IRQTable[EXTI4_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel1_IRQHandler (void)
{
   IRQTable[DMA1_Channel1_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel2_IRQHandler (void)
{
   IRQTable[DMA1_Channel2_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel3_IRQHandler (void)
{
   IRQTable[DMA1_Channel3_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel4_IRQHandler (void)
{
   IRQTable[DMA1_Channel4_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel5_IRQHandler (void)
{
   IRQTable[DMA1_Channel5_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel6_IRQHandler (void)
{
   IRQTable[DMA1_Channel6_IRQHandler_ID]();
   tn_int_exit();
}

void DMA1_Channel7_IRQHandler (void)
{
   IRQTable[DMA1_Channel7_IRQHandler_ID]();
   tn_int_exit();
}

void ADC1_2_IRQHandler (void)
{
   IRQTable[ADC1_2_IRQHandler_ID]();
   tn_int_exit();
}

void USB_HP_CAN1_TX_IRQHandler (void)
{
   IRQTable[USB_HP_CAN1_TX_IRQHandler_ID]();
   tn_int_exit();
}

void USB_LP_CAN1_RX0_IRQHandler (void)
{
   IRQTable[USB_LP_CAN1_RX0_IRQHandler_ID]();
   tn_int_exit();
}

void CAN1_RX1_IRQHandler (void)
{
   IRQTable[CAN1_RX1_IRQHandler_ID]();
   tn_int_exit();
}

void CAN1_SCE_IRQHandler (void)
{
   IRQTable[CAN1_SCE_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI9_5_IRQHandler (void)
{
   IRQTable[EXTI9_5_IRQHandler_ID]();
   tn_int_exit();
}

void TIM1_BRK_IRQHandler (void)
{
   IRQTable[TIM1_BRK_IRQHandler_ID]();
   tn_int_exit();
}

void TIM1_UP_IRQHandler (void)
{
   IRQTable[TIM1_UP_IRQHandler_ID]();
   tn_int_exit();
}

void TIM1_TRG_COM_IRQHandler (void)
{
   IRQTable[TIM1_TRG_COM_IRQHandler_ID]();
   tn_int_exit();
}

void TIM1_CC_IRQHandler (void)
{
   IRQTable[TIM1_CC_IRQHandler_ID]();
   tn_int_exit();
}

void TIM2_IRQHandler (void)
{
   IRQTable[TIM2_IRQHandler_ID]();
   tn_int_exit();
}

void TIM3_IRQHandler (void)
{
   IRQTable[TIM3_IRQHandler_ID]();
   tn_int_exit();
}

void TIM4_IRQHandler (void)  
{
   IRQTable[TIM4_IRQHandler_ID]();
   tn_int_exit();
}

void I2C1_EV_IRQHandler (void)
{
   IRQTable[I2C1_EV_IRQHandler_ID]();
   tn_int_exit();
}

void I2C1_ER_IRQHandler (void)
{
   IRQTable[I2C1_ER_IRQHandler_ID]();
   tn_int_exit();
}

void I2C2_EV_IRQHandler (void)
{
   IRQTable[I2C2_EV_IRQHandler_ID]();
   tn_int_exit();
}

void I2C2_ER_IRQHandler (void)
{
   IRQTable[I2C2_ER_IRQHandler_ID]();
   tn_int_exit();
}

void SPI1_IRQHandler (void)
{
   IRQTable[SPI1_IRQHandler_ID]();
   tn_int_exit();
}

void SPI2_IRQHandler (void)
{
   IRQTable[SPI2_IRQHandler_ID]();
   tn_int_exit();
}

void USART1_IRQHandler (void)
{
   IRQTable[USART1_IRQHandler_ID]();
   tn_int_exit();
}

void USART2_IRQHandler (void)
{
   IRQTable[USART2_IRQHandler_ID]();
   tn_int_exit();
}

void USART3_IRQHandler (void)
{
   IRQTable[USART3_IRQHandler_ID]();
   tn_int_exit();
}

void EXTI15_10_IRQHandler (void)
{
   IRQTable[EXTI15_10_IRQHandler_ID]();
   tn_int_exit();
}

void RTCAlarm_IRQHandler (void)
{
   IRQTable[RTCAlarm_IRQHandler_ID]();
   tn_int_exit();
}

void USBWakeUp_IRQHandler (void)
{
   IRQTable[USBWakeUp_IRQHandler_ID]();
   tn_int_exit();
}

void TIM8_BRK_IRQHandler (void)
{
   IRQTable[TIM8_BRK_IRQHandler_ID]();
   tn_int_exit();
}

void TIM8_UP_IRQHandler (void)
{
   IRQTable[TIM8_UP_IRQHandler_ID]();
   tn_int_exit();
}

void TIM8_TRG_COM_IRQHandler (void)
{
   IRQTable[TIM8_TRG_COM_IRQHandler_ID]();
   tn_int_exit();
}

void TIM8_CC_IRQHandler (void)
{
   IRQTable[TIM8_CC_IRQHandler_ID]();
   tn_int_exit();
}

void ADC3_IRQHandler (void)
{
   IRQTable[ADC3_IRQHandler_ID]();
   tn_int_exit();
}

void FSMC_IRQHandler (void)
{
   IRQTable[FSMC_IRQHandler_ID]();
   tn_int_exit();
}

void SDIO_IRQHandler (void)
{
   IRQTable[SDIO_IRQHandler_ID]();
   tn_int_exit();
}

void TIM5_IRQHandler (void)
{
   IRQTable[TIM5_IRQHandler_ID]();
   tn_int_exit();
}

void SPI3_IRQHandler (void)
{
   IRQTable[SPI3_IRQHandler_ID]();
   tn_int_exit();
}

void UART4_IRQHandler (void)
{
   IRQTable[UART4_IRQHandler_ID]();
   tn_int_exit();
}

void UART5_IRQHandler (void)
{
   IRQTable[UART5_IRQHandler_ID]();
   tn_int_exit();
}

void TIM6_IRQHandler (void)
{
   IRQTable[TIM6_IRQHandler_ID]();
   tn_int_exit();
}

void TIM7_IRQHandler (void)
{
   IRQTable[TIM7_IRQHandler_ID]();
   tn_int_exit();
}

void DMA2_Channel1_IRQHandler (void)
{
   IRQTable[DMA2_Channel1_IRQHandler_ID]();
   tn_int_exit();
}

void DMA2_Channel2_IRQHandler (void)
{
   IRQTable[DMA2_Channel2_IRQHandler_ID]();
   tn_int_exit();
}

void DMA2_Channel3_IRQHandler (void)
{
   IRQTable[DMA2_Channel3_IRQHandler_ID]();
   tn_int_exit();
}

void DMA2_Channel4_5_IRQHandler (void)
{
   IRQTable[DMA2_Channel4_5_IRQHandler_ID]();
   tn_int_exit();
}

#endif /* TN_ARCH_CM3 && TN_PORT_STM32 */
/*** EOF ***/
